quantizationtools.QGridTempoLookup
==================================

.. inheritance-diagram:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup
   :private-bases:

.. autoclass:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.beatspan

.. autoattribute:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.tempo

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.clear

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.copy

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.fromkeys

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.get

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.has_key

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.items

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.iteritems

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.iterkeys

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.itervalues

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.keys

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.pop

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.popitem

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.setdefault

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.update

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.values

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.viewitems

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.viewkeys

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.viewvalues

    Inherited from `__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__cmp__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__contains__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__delitem__

    Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__eq__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__ge__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__getitem__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__gt__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__iter__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__le__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__len__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__lt__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__ne__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__repr__

    Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__setitem__

    Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__str__

    Inherited from `__builtin__.object`
